from ftw.calendarwidget.testing import FTW_CALENDARWIDGET_INTEGRATION_TESTING
from plone.app.testing import TEST_USER_NAME, TEST_USER_PASSWORD, TEST_USER_ID
from plone.testing.z2 import Browser
from unittest2 import TestCase
from Products.CMFCore.utils import getToolByName
from Products.Archetypes import atapi
from ftw.calendarwidget.browser.widgets import FtwCalendarWidget
from plone.app.testing import login
from plone.app.testing import setRoles
import transaction


class TestCalendarwidget(TestCase):

    layer = FTW_CALENDARWIDGET_INTEGRATION_TESTING

    def setUp(self):
        super(TestCalendarwidget, self).setUp()

        self.portal = self.layer['portal']
        self.portal_url = self.portal.portal_url()
        self.browser = Browser(self.layer['app'])
        self.browser.handleErrors = False

        setRoles(self.portal, TEST_USER_ID, ['Manager'])

        login(self.portal, TEST_USER_NAME)
        self.doc = self.portal.get(
            self.portal.invokeFactory('Document', 'document'))
        transaction.commit()

    def test_js_installed(self):
        jsregistry = getToolByName(self.portal, 'portal_javascripts')

        self.assertTrue('++resource++ftw.calendarwidget/ftw_calendar.js' in jsregistry.getResourceIds())

    def test_widget_config(self):
        schema = atapi.Schema((
            atapi.DateTimeField(
            name='mydate',
            widget=FtwCalendarWidget(label='My Date')),
        ))
        widget = schema['mydate'].widget
        self.assertEquals(widget.helper_js, ())
        self.assertEquals(widget.helper_css, ('jscalendar/calendar-system.css', ))


    def test_widget_rendering(self):
        self.browser.addHeader('Authorization', 'Basic %s:%s' % (
                TEST_USER_NAME, TEST_USER_PASSWORD, ))
        self.browser.open(self.doc.absolute_url() + '/edit')

        # The test setup patches the ExtensibleMetadata schema

        # Check if there is a label
        self.assertIn('MyDate', self.browser.contents)


    def tearDown(self):
        super(TestCalendarwidget, self).tearDown()
        self.doc.wl_clearLocks()
        self.portal.manage_delObjects(['document', ])
        transaction.commit()



from Products.Archetypes.Widget import CalendarWidget


class FtwCalendarWidget(CalendarWidget):
    _properties = CalendarWidget._properties.copy()
    _properties.update({
            'macro': "ftw_calendar",
            'format': '',  # time.strftime string
            'show_ymd': True,
            'show_hm': True,
            'starting_year': None,
            'ending_year': None,
            'future_years': None,
            'helper_js': (),
            'helper_css': ('jscalendar/calendar-system.css',),
            })



from plone.app.testing import IntegrationTesting
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import PloneSandboxLayer
from plone.app.testing import applyProfile
from plone.testing import z2
from zope.configuration import xmlconfig
import collective.js.jqueryui
import ftw.calendarwidget


class FtwCalendarWidgetLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE, )

    def setUpZope(self, app, configurationContext):

        # Patch effectiveDate, so our FtwCalendarwidget is used
        from ftw.calendarwidget.browser.widgets import FtwCalendarWidget
        from Products.ATContentTypes.content.base import registerATCT
        from Products.ATContentTypes.content.document import ATDocument
        from Products.ATContentTypes.content.document import PROJECTNAME

        ATDocument.schema['effectiveDate'].widget = FtwCalendarWidget(
                label='MyDate'
            )

        registerATCT(ATDocument, PROJECTNAME)

        # Load ZCML

        xmlconfig.file('configure.zcml',
            ftw.calendarwidget,
            context=configurationContext)
        xmlconfig.file('configure.zcml',
            collective.js.jqueryui,
            context=configurationContext)

        # installProduct() is *only* necessary for packages outside
        # the Products.* namespace which are also declared as Zope 2 products,
        # using <five:registerPackage /> in ZCML.
        z2.installProduct(app, 'ftw.calendarwidget')
        z2.installProduct(app, 'collective.js.jqueryui')

    def setUpPloneSite(self, portal):
        # Install into Plone site using portal_setup
        applyProfile(portal, 'ftw.calendarwidget:default')


FTW_CALENDARWIDGET_FIXTURE = FtwCalendarWidgetLayer()
FTW_CALENDARWIDGET_INTEGRATION_TESTING = IntegrationTesting(
    bases=(FTW_CALENDARWIDGET_FIXTURE, ),
    name="ftw.calendarwidget:Integration")
